Package 'ggwizard'

Title: Create Beautiful ggplot2 Charts Without Coding
Description: A point-and-click Shiny application that guides non-programmers through importing CSV or Excel data, previewing it, and generating publication-quality ggplot2 charts. Supports bar, line, scatter, time series, histogram, box, violin, and area plots with full customisation of labels, themes, colours, and font styles. Outputs are saved to a timestamped folder along with a reproducible R script and a run log.
Authors: Ebenezer Ogoe [aut, cre]
Maintainer: Ebenezer Ogoe <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-06-26 02:47:09 UTC
Source: https://github.com/ebenogoe/ggwizard

Help Index


Run the ggWizard Shiny Application

Description

Launches the ggWizard point-and-click chart builder in a browser window.

Usage

run_app(
  onStart = NULL,
  options = list(),
  enableBookmarking = NULL,
  uiPattern = "/",
  ...
)

Arguments

onStart

A function that will be called before the app is actually run. This is only needed for shinyAppObj, since in the shinyAppDir case, a global.R file can be used for this purpose.

options

Named options that should be passed to the runApp call (these can be any of the following: "port", "launch.browser", "host", "quiet", "display.mode" and "test.mode"). You can also specify width and height parameters which provide a hint to the embedding environment about the ideal height/width for the app.

enableBookmarking

Can be one of "url", "server", or "disable". The default value, NULL, will respect the setting from any previous calls to enableBookmarking(). See enableBookmarking() for more information on bookmarking your app.

uiPattern

A regular expression that will be applied to each GET request to determine whether the ui should be used to handle the request. Note that the entire request path must match the regular expression in order for the match to be considered successful.

...

Arguments passed to [golem::get_golem_options()].